Module: Whatsapp
- Defined in:
- lib/ruby/whatsapp.rb,
lib/ruby/whatsapp/media.rb,
lib/ruby/whatsapp/client.rb,
lib/ruby/whatsapp/railtie.rb,
lib/ruby/whatsapp/version.rb,
lib/ruby/whatsapp/webhook.rb,
lib/ruby/whatsapp/messages.rb,
lib/ruby/whatsapp/configuration.rb,
lib/ruby/whatsapp/messages/base.rb,
lib/ruby/whatsapp/messages/text.rb,
lib/ruby/whatsapp/request_error.rb,
lib/ruby/whatsapp/webhook/entry.rb,
lib/ruby/whatsapp/webhook/error.rb,
lib/ruby/whatsapp/messages/audio.rb,
lib/ruby/whatsapp/messages/image.rb,
lib/ruby/whatsapp/messages/video.rb,
lib/ruby/whatsapp/webhook/change.rb,
lib/ruby/whatsapp/webhook/status.rb,
lib/ruby/whatsapp/instrumentation.rb,
lib/ruby/whatsapp/webhook/contact.rb,
lib/ruby/whatsapp/webhook/history.rb,
lib/ruby/whatsapp/webhook/message.rb,
lib/ruby/whatsapp/messages/address.rb,
lib/ruby/whatsapp/messages/sticker.rb,
lib/ruby/whatsapp/webhook/messages.rb,
lib/ruby/whatsapp/webhook/metadata.rb,
lib/ruby/whatsapp/webhook/security.rb,
lib/ruby/whatsapp/message_templates.rb,
lib/ruby/whatsapp/messages/contacts.rb,
lib/ruby/whatsapp/messages/document.rb,
lib/ruby/whatsapp/messages/location.rb,
lib/ruby/whatsapp/messages/reaction.rb,
lib/ruby/whatsapp/messages/response.rb,
lib/ruby/whatsapp/messages/template.rb,
lib/ruby/whatsapp/response_handling.rb,
lib/ruby/whatsapp/webhook/installer.rb,
lib/ruby/whatsapp/webhook/signature.rb,
lib/ruby/whatsapp/messages/interactive.rb,
lib/ruby/whatsapp/utils/language_codes.rb,
lib/ruby/whatsapp/webhook/message/base.rb,
lib/ruby/whatsapp/webhook/message/text.rb,
lib/ruby/whatsapp/webhook/notification.rb,
lib/ruby/whatsapp/webhook/verification.rb,
lib/ruby/whatsapp/messages/contacts/org.rb,
lib/ruby/whatsapp/messages/contacts/url.rb,
lib/ruby/whatsapp/webhook/message/audio.rb,
lib/ruby/whatsapp/webhook/message/image.rb,
lib/ruby/whatsapp/webhook/message/media.rb,
lib/ruby/whatsapp/webhook/message/order.rb,
lib/ruby/whatsapp/webhook/message/video.rb,
lib/ruby/whatsapp/webhook/unknown_field.rb,
lib/ruby/whatsapp/messages/contacts/name.rb,
lib/ruby/whatsapp/webhook/account_alerts.rb,
lib/ruby/whatsapp/webhook/account_update.rb,
lib/ruby/whatsapp/webhook/message/button.rb,
lib/ruby/whatsapp/webhook/message/system.rb,
lib/ruby/whatsapp/webhook/status/pricing.rb,
lib/ruby/whatsapp/messages/contacts/email.rb,
lib/ruby/whatsapp/messages/contacts/phone.rb,
lib/ruby/whatsapp/webhook/message/context.rb,
lib/ruby/whatsapp/webhook/message/sticker.rb,
lib/ruby/whatsapp/webhook/message/unknown.rb,
lib/ruby/whatsapp/message_templates/button.rb,
lib/ruby/whatsapp/webhook/automatic_events.rb,
lib/ruby/whatsapp/webhook/message/contacts.rb,
lib/ruby/whatsapp/webhook/message/document.rb,
lib/ruby/whatsapp/webhook/message/location.rb,
lib/ruby/whatsapp/webhook/message/reaction.rb,
lib/ruby/whatsapp/webhook/message/referral.rb,
lib/ruby/whatsapp/webhook/user_preferences.rb,
lib/ruby/whatsapp/message_templates/example.rb,
lib/ruby/whatsapp/messages/contacts/address.rb,
lib/ruby/whatsapp/messages/contacts/contact.rb,
lib/ruby/whatsapp/messages/interactive/base.rb,
lib/ruby/whatsapp/messages/interactive/body.rb,
lib/ruby/whatsapp/messages/location_request.rb,
lib/ruby/whatsapp/webhook/partner_solutions.rb,
lib/ruby/whatsapp/message_templates/response.rb,
lib/ruby/whatsapp/message_templates/statuses.rb,
lib/ruby/whatsapp/message_templates/template.rb,
lib/ruby/whatsapp/messages/response/contacts.rb,
lib/ruby/whatsapp/messages/response/messages.rb,
lib/ruby/whatsapp/messages/template/language.rb,
lib/ruby/whatsapp/webhook/smb_app_state_sync.rb,
lib/ruby/whatsapp/webhook/smb_message_echoes.rb,
lib/ruby/whatsapp/message_templates/component.rb,
lib/ruby/whatsapp/messages/interactive/footer.rb,
lib/ruby/whatsapp/messages/interactive/header.rb,
lib/ruby/whatsapp/messages/template/component.rb,
lib/ruby/whatsapp/messages/template/parameter.rb,
lib/ruby/whatsapp/webhook/message/interactive.rb,
lib/ruby/whatsapp/webhook/status/conversation.rb,
lib/ruby/whatsapp/message_templates/button/otp.rb,
lib/ruby/whatsapp/message_templates/button/url.rb,
lib/ruby/whatsapp/message_templates/categories.rb,
lib/ruby/whatsapp/webhook/message/contacts/org.rb,
lib/ruby/whatsapp/webhook/message/contacts/url.rb,
lib/ruby/whatsapp/message_templates/button/base.rb,
lib/ruby/whatsapp/messages/mark_message_as_read.rb,
lib/ruby/whatsapp/webhook/account_review_update.rb,
lib/ruby/whatsapp/webhook/message/contacts/name.rb,
lib/ruby/whatsapp/message_templates/placeholders.rb,
lib/ruby/whatsapp/message_templates/value_object.rb,
lib/ruby/whatsapp/webhook/message/contacts/email.rb,
lib/ruby/whatsapp/webhook/message/contacts/phone.rb,
lib/ruby/whatsapp/message_templates/component_set.rb,
lib/ruby/whatsapp/message_templates/response/node.rb,
lib/ruby/whatsapp/messages/interactive/url_button.rb,
lib/ruby/whatsapp/webhook/account_update/ban_info.rb,
lib/ruby/whatsapp/message_templates/component/base.rb,
lib/ruby/whatsapp/message_templates/component/body.rb,
lib/ruby/whatsapp/webhook/message/contacts/address.rb,
lib/ruby/whatsapp/webhook/message/contacts/contact.rb,
lib/ruby/whatsapp/webhook/phone_number_name_update.rb,
lib/ruby/whatsapp/webhook/template_category_update.rb,
lib/ruby/whatsapp/message_templates/response/paging.rb,
lib/ruby/whatsapp/messages/interactive/list_buttons.rb,
lib/ruby/whatsapp/message_templates/button/copy_code.rb,
lib/ruby/whatsapp/message_templates/component/footer.rb,
lib/ruby/whatsapp/message_templates/component/header.rb,
lib/ruby/whatsapp/message_templates/library_template.rb,
lib/ruby/whatsapp/message_templates/response/created.rb,
lib/ruby/whatsapp/message_templates/response/summary.rb,
lib/ruby/whatsapp/messages/interactive/reply_buttons.rb,
lib/ruby/whatsapp/webhook/business_capability_update.rb,
lib/ruby/whatsapp/webhook/message/order/product_item.rb,
lib/ruby/whatsapp/message_templates/component/buttons.rb,
lib/ruby/whatsapp/message_templates/parameter_formats.rb,
lib/ruby/whatsapp/messages/interactive/media_carousel.rb,
lib/ruby/whatsapp/webhook/phone_number_quality_update.rb,
lib/ruby/whatsapp/message_templates/button/quick_reply.rb,
lib/ruby/whatsapp/message_templates/component/carousel.rb,
lib/ruby/whatsapp/webhook/payment_configuration_update.rb,
lib/ruby/whatsapp/message_templates/button/phone_number.rb,
lib/ruby/whatsapp/message_templates/response/collection.rb,
lib/ruby/whatsapp/messages/interactive/product_carousel.rb,
lib/ruby/whatsapp/webhook/smb_app_state_sync/state_sync.rb,
lib/ruby/whatsapp/webhook/message_template_status_update.rb,
lib/ruby/whatsapp/webhook/message_template_quality_update.rb,
lib/ruby/whatsapp/message_templates/response/quality_score.rb,
lib/ruby/whatsapp/messages/interactive/media_carousel/card.rb,
lib/ruby/whatsapp/message_templates/component/carousel/card.rb,
lib/ruby/whatsapp/messages/interactive/list_buttons/section.rb,
lib/ruby/whatsapp/messages/interactive/reply_buttons/button.rb,
lib/ruby/whatsapp/message_templates/button/otp/supported_app.rb,
lib/ruby/whatsapp/messages/interactive/product_carousel/card.rb,
lib/ruby/whatsapp/webhook/message_template_components_update.rb,
lib/ruby/whatsapp/messages/interactive/list_buttons/section/row.rb,
lib/ruby/whatsapp/message_templates/component/limited_time_offer.rb,
lib/ruby/whatsapp/message_templates/library_template/body_inputs.rb,
lib/ruby/whatsapp/messages/interactive/media_carousel/card/button.rb,
lib/ruby/whatsapp/message_templates/library_template/button_inputs.rb,
lib/ruby/whatsapp/messages/interactive/media_carousel/card/button/quick_reply.rb
Defined Under Namespace
Modules: ResponseHandling, Utils, Webhook Classes: Client, Configuration, Error, Instrumentation, Media, MessageTemplates, Messages, Railtie, RequestError
Constant Summary collapse
- VERSION =
"0.3.0"
Class Attribute Summary collapse
-
.configuration ⇒ Whatsapp::Configuration
Returns the global configuration, lazily initializing it on first use.
Class Method Summary collapse
-
.configure {|configuration| ... } ⇒ Whatsapp::Configuration
Yields the configuration for mutation and returns it.
Class Attribute Details
.configuration ⇒ Whatsapp::Configuration
Returns the global configuration, lazily initializing it on first use.
27 28 29 |
# File 'lib/ruby/whatsapp.rb', line 27 def configuration @configuration ||= Configuration.new end |
Class Method Details
.configure {|configuration| ... } ⇒ Whatsapp::Configuration
Yields the configuration for mutation and returns it.
34 35 36 37 38 |
# File 'lib/ruby/whatsapp.rb', line 34 def configure yield(configuration) if block_given? configuration end |