Module: Whatsapp::MessageTemplates::Button::Otp::OtpTypes

Defined in:
lib/ruby/whatsapp/message_templates/button/otp.rb

Overview

How the recipient hands the code back to the business.

Constant Summary collapse

COPY_CODE =

Copies the code to the clipboard.

"COPY_CODE"
ONE_TAP =

Autofills the code into the requesting app.

"ONE_TAP"
ZERO_TAP =

Delivers the code to a broadcast receiver with no user action.

"ZERO_TAP"
NO_BUTTONS =

Renders no button at all.

"NO_BUTTONS"
ALL =
[COPY_CODE, ONE_TAP, ZERO_TAP, NO_BUTTONS].freeze
REQUIRING_SUPPORTED_APPS =

OTP types that hand the code to an app and so must declare which apps are allowed to receive it.

[ONE_TAP, ZERO_TAP].freeze