Class: Whatsapp::Messages::Sticker
- Defined in:
- lib/ruby/whatsapp/messages/sticker.rb
Overview
Sticker messages display animated or static sticker images in a WhatsApp message. Source: https://developers.facebook.com/documentation/business-messaging/whatsapp/messages/sticker-messages
Defined Under Namespace
Modules: Defaults
Instance Attribute Summary collapse
Attributes inherited from Base
Instance Method Summary collapse
-
#initialize(id: nil, link: nil) ⇒ Sticker
constructor
A new instance of Sticker.
-
#serialize ⇒ Hash
Serializes the sticker message to a hash format suitable for the WhatsApp API.
Constructor Details
#initialize(id: nil, link: nil) ⇒ Sticker
Returns a new instance of Sticker.
27 28 29 30 31 32 33 34 |
# File 'lib/ruby/whatsapp/messages/sticker.rb', line 27 def initialize(id: nil, link: nil, **) super(**) @id = id @link = link validate! end |
Instance Attribute Details
#id ⇒ String
14 15 16 |
# File 'lib/ruby/whatsapp/messages/sticker.rb', line 14 def id @id end |
#link ⇒ String
18 19 20 |
# File 'lib/ruby/whatsapp/messages/sticker.rb', line 18 def link @link end |